==> apache-pulsar-2.10.0-src.tar.gz: apache-pulsar-2.10.0-src/pulsar-broker/src/test/java/org/apache/pulsar/broker/service/persistent/PersistentSubscriptionMessageDispatchStreamingDispatcherThrottlingTest.java <==
/**
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
package org.apache.pulsar.broker.service.persistent;

import org.apache.pulsar.broker.service.streamingdispatch.StreamingDispatcher;
import org.apache.pulsar.client.api.SubscriptionMessageDispatchThrottlingTest;
import org.testng.annotations.BeforeMethod;
import org.testng.annotations.Test;

/**
 * SubscriptionMessageDispatchThrottlingTest with {@link StreamingDispatcher}
 */
@Test(groups = "flaky")
public class PersistentSubscriptionMessageDispatchStreamingDispatcherThrottlingTest
    extends SubscriptionMessageDispatchThrottlingTest {

    @BeforeMethod
    @Override
    protected void setup() throws Exception {
        super.setup();
        conf.setStreamingDispatch(true);
    }
}

==> apache-pulsar-2.11.1-src.tar.gz: apache-pulsar-2.11.1-src/pulsar-broker/src/test/java/org/apache/pulsar/broker/service/persistent/PersistentSubscriptionMessageDispatchStreamingDispatcherThrottlingTest.java <==
/**
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
package org.apache.pulsar.broker.service.persistent;

import org.apache.pulsar.broker.service.streamingdispatch.StreamingDispatcher;
import org.apache.pulsar.client.api.SubscriptionMessageDispatchThrottlingTest;
import org.testng.annotations.BeforeClass;
import org.testng.annotations.Test;

/**
 * SubscriptionMessageDispatchThrottlingTest with {@link StreamingDispatcher}
 */
@Test(groups = "flaky")
public class PersistentSubscriptionMessageDispatchStreamingDispatcherThrottlingTest
    extends SubscriptionMessageDispatchThrottlingTest {

    @BeforeClass
    @Override
    protected void setup() throws Exception {
        super.setup();
        conf.setStreamingDispatch(true);
    }
}
